@@ -29,6 +29,8 @@ sub new {
 
 sub theme { $Theme };
 
+sub has_remotelist { };
+
 1;
 
 =head1 NAME
@@ -64,6 +66,10 @@ Implement the name() method for this class.
 
 Return the theme name (C<any>).
 
+=item has_remotelist()
+
+Always return false.
+
 =back
 
 =head1 CONTRIBUTOR
@@ -72,6 +78,10 @@ Philippe Bruhat, upon request of Sbastien Aperghis-Tramoni.
 
 Introduced in version 0.12, published on March 7, 2005.
 
+Updated to conform with interface changes required by
+C<Acme::MetaSyntactic::Updatable> in version 0.49, published
+on November 21, 2005.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>.
